spacepy.poppy.plot_two_ppro — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- PoPPy - Point Processes in Python »

# spacepy.poppy.plot_two_ppro

`spacepy.poppy.` `plot_two_ppro`(pprodata, pproref, ratio=None, norm=False, title=None, xscale=None, figsize=None, dpi=80, ylim=[None, None], log=False, xticks=None, yticks=None)

  Overplots two PPro objects

  Parameters: | pprodata : PPro first point process to plot (in blue) pproref : PPro second process to plot (in red) ratio : float multiply L{pprodata} by this ratio before plotting, useful for comparing processes of different magnitude norm : boolean normalize everything to L{pproref}, i.e. the association number for L{pproref} will always plot as 1. title : string title to put on the plot xscale : float scale x-axis by this factor (e.g. 60.0 to convert seconds to minutes) figsize : : passed through to matplotlib.pyplot.figure dpi : int passed through to matplotlib.pyplot.figure ylim : list [minimum, maximum] values of y for the axis log : bollean True for a log plot xticks : sequence or float if provided, a list of tickmarks for the X axis yticks : sequance or float if provided, a list of tickmarks for the Y axis

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- PoPPy - Point Processes in Python »